@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -825,11 +825,11 @@ clipboard_manager_watch_cb (MsdClipboardManager *manager,
         GdkDisplay *display;
 
         display = gdk_display_get_default ();
-        gdkwin = gdk_window_lookup_for_display (display, window);
+        gdkwin = gdk_x11_window_lookup_for_display (display, window);
 
         if (is_start) {
                 if (gdkwin == NULL) {
-                        gdkwin = gdk_window_foreign_new_for_display (display, window);
+                        gdkwin = gdk_x11_window_foreign_new_for_display (display, window);
                 } else {
                         g_object_ref (gdkwin);
                 }
