@@ -421,10 +421,18 @@ get_exec_environment (XEvent *xevent)
         int        i;
         int        display_index = -1;
         GdkScreen *screen = NULL;
+#if GTK_CHECK_VERSION (3, 0, 0)
+        GdkWindow *window = gdk_x11_window_lookup_for_display (gdk_display_get_default (), xevent->xkey.root);
+#else
         GdkWindow *window = gdk_xid_table_lookup (xevent->xkey.root);
+#endif
 
         if (window) {
+#if GTK_CHECK_VERSION (3, 0, 0)
+                screen = gdk_window_get_screen (window);
+#else
                 screen = gdk_drawable_get_screen (GDK_DRAWABLE (window));
+#endif
         }
 
         g_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
