@@ -65,7 +65,7 @@ static const gchar *BUS_NAMES[] = {"org.mpris.MediaPlayer2.audacious",
                                    "org.mpris.MediaPlayer2.quodlibet",
                                    "org.mpris.MediaPlayer2.guayadeque",
                                    "org.mpris.MediaPlayer2.amarok",
-                                   "org.mpris.MediaPlayer2.googlemusicframe",
+                                   "org.mpris.MediaPlayer2.nuvolaplayer",
                                    "org.mpris.MediaPlayer2.xbmc",
                                    "org.mpris.MediaPlayer2.xnoise",
                                    "org.mpris.MediaPlayer2.gmusicbrowser",
